@@ -18,10 +18,10 @@ our @EXPORT_OK = qw(
     is_empty    is_sub   flow        eql
     to_pairs    for_each apply       get
     second      range    pops        pushes
-    shifts      unshifts
+    shifts      unshifts once
 );
 
-our $VERSION = '0.30';
+our $VERSION = '0.32';
 
 use constant ARG_PLACE_HOLDER => {};
 
@@ -37,6 +37,22 @@ sub identity {
     return $args;
 }
 
+sub once {
+    my $func            = shift // \&noop;
+    my $was_called_once = 0;
+    my $result;
+
+    return sub {
+        if ($was_called_once) {
+            return $result;
+        }
+
+        $was_called_once++;
+        $result = $func->(@_);
+        return $result;
+    }
+}
+
 # Forgive me below father, for I have sinned.
 # Seriously, I can't figure a simpler way to do this...
 # TODO: Please refactor this eventually...
@@ -117,15 +133,19 @@ sub apply {
 }
 
 sub flow {
-    my $args = [@_];
+    my $funcs = [@_];
 
-    if (ref $args->[0] ne 'CODE') {
+    if (ref $funcs->[0] ne 'CODE') {
         return \&noop;
     }
 
     return sub {
-        my $start_value = shift // noop;
-        chain($start_value, spread($args));
+        my $args = [@_];
+
+        return chain(
+            sub { first($funcs)->(spread($args)) },
+            spread(drop($funcs)),
+        );
     }
 }
 
@@ -618,6 +638,23 @@ Decrements the supplied number by 1
 
 =cut
 
+=head2 once
+
+Creates a function that is restricted to invoking func once.
+Repeat calls to the function return the value of the first invocation.
+
+    my $times_called = 0;
+    my $sub          = once(sub {
+        $times_called++;
+        return "I was only called $times_called time"
+    });
+
+    $sub->(); # "I was only called 1 time"
+    $sub->(); # "I was only called 1 time"
+    $sub->(); # etc
+
+=cut
+
 =head2 apply
 
 Calls the supplied function with the array of arguments, spreading the
